@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 
-our $VERSION     = '0.097';
+our $VERSION     = '0.098';
 $VERSION = eval $VERSION;
 
 1;
@@ -18,7 +18,7 @@ Gtk2::Ex::DbLinker - Use sql or orm objects to build a gtk2 Gui
 
 =head1 VERSION
 
-version  0.097 but see version at the end of MYMETA.yml to check that I'm correct here...
+version  0.098 but see version at the end of MYMETA.yml to check that I'm correct here...
 
 =head1 INSTALLATION
 
@@ -127,9 +127,7 @@ C<runeexample2_rdb.pl> uses Rose::Data::Object. The database is the same as exam
 
 =head1 SUPPORT
 
-Any Gk2::Ex::DbLinker questions or problems can be posted to the the mailing list. To subscribe to the list or view the archives, go here: 
-L<http://groups.google.com/group/gtk2-ex-dblinker>. 
-You may also send emails to gtk2-ex-dblinker@googlegroups.com. 
+Any Gk2::Ex::DbLinker questions or problems can be posted to me (rappazf) on my gmail account. 
 
 The current state of the source can be extract using Mercurial from
 L<http://code.google.com/p/gtk2-ex-dblinker/>.
