@@ -64,7 +64,7 @@ see the implementing modules for the details
 
 =head1 AUTHOR
 
-FranE<ccedil>ois Rappaz <rappazf@gmail.com>
+FranE<ccedil>ois Rappaz <rappazf at gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
