@@ -1037,9 +1037,7 @@ Revert the row to the original state in displaying the values fetch from the dat
 
 =head1 SUPPORT
 
-Any Gk2::Ex::DbLinker questions or problems can be posted to the the mailing list. To subscribe to the list or view the archives, go here: 
-L<http://groups.google.com/group/gtk2-ex-dblinker>. 
-You may also send emails to gtk2-ex-dblinker@googlegroups.com. 
+Any Gk2::Ex::DbLinker questions or problems can be posted to me (rappazf) on my gmail account. 
 
 The current state of the source can be extract using Mercurial from
 L<http://code.google.com/p/gtk2-ex-dblinker/>.
