@@ -10,6 +10,7 @@ use strict;
 use warnings;
 use  Carp;
 use Data::Dumper;
+use Try::Tiny;
 
 $Class::Interface::CONFESS = 1;
 
@@ -155,6 +156,7 @@ sub save{
 	my $self = shift;
 	my $row;
 	my $result;
+	my $done;
 	if ($self->{new_row}){
 		$self->{log}->debug(" save new row " );
 		$row = $self->{new_row};
@@ -178,14 +180,25 @@ sub save{
 		#$row =  $self->{rs}->find(@{$self->{data}[$pos]});
 		$row = $self->{current_row};
 		# $self->{log}->debug(Dumper($row));
-		$result = $row->update;
+		try {
+			$result = $row->update;
+			$self->{log}->debug("saving and unsetting new row");
+			$done = 1;
+		} catch {
+			carp ("Can't save record : $_");
+			$done = 0;
+		}	
+
+		
+
 	}
-	$self->{log}->debug("saving and unsetting new row");
+
 	#$row->save;
 	#don't delete new_row is inserting in the db gets wrong
 	if ($result) {
 		$self->{new_row} = undef;
 	}
+	return $done;
 }
 sub new_row {
 	my ($self ) = @_;
@@ -529,6 +542,13 @@ The methods belows are used by the Form module and you should not have to use th
 
 =head2 C<save();>
 
+return 1 on success or 0. Check this if you implement a locking mecanism within a Result module with DBIx::Class::OptimisticLocking:
+
+        __PACKAGE__->load_components(qw/OptimisticLocking Core/);
+        __PACKAGE__->optimistic_locking_strategy('dirty'); 
+
+This will prevent a row from being changed by two users in the same time.
+
 =head2 C<delete();>
 
 =head2 C<set_row_pos( $new_pos ); >
@@ -569,9 +589,7 @@ Return an array of auto incremented primary key(s) from the underlying result_so
 
 =head1 SUPPORT
 
-Any Gk2::Ex::DbLinker questions or problems can be posted to the the mailing list. To subscribe to the list or view the archives, go here: 
-L<http://groups.google.com/group/gtk2-ex-dblinker>. 
-You may also send emails to gtk2-ex-dblinker@googlegroups.com. 
+Any Gk2::Ex::DbLinker questions or problems can be posted to me (rappazf) on my gmail account. 
 
 The current state of the source can be extract using Mercurial from
 L<http://code.google.com/p/gtk2-ex-dblinker/>.
