@@ -406,6 +406,7 @@ sub delete {
 sub apply{
 	my $self = shift;
 	my $row;
+	my $done;
 	#we are adding a new record if $pos < 0
 	$self->{log}->debug("apply: pos : " . $self->{pos} );
 	if ($self->{pos}<0){
@@ -482,7 +483,7 @@ sub apply{
 	   }
 	} #foreach
 	#$row->save;
-	$self->{dman}->save;
+	$done = $self->{dman}->save;
 	# $self->{log}->debug("nofm: " . $row->nofm);
 	# $self->set_rs_range;
 
@@ -502,11 +503,11 @@ sub apply{
 	}
 			#push @pk_val, $id
 		
-	if ($self->{after_insert}){
+	if ($done && $self->{after_insert}){
 		my $coderef = $self->{after_insert};
 		&$coderef(undef, \%pk_val );
 	}
-	if ($self->{pos}<0){
+	if ($done && $self->{pos}<0){
 		my $last = $self->{dman}->row_count -1;
 		$self->{log}->debug("last is " . $last );
 		$self->_display_data( $last );
@@ -520,10 +521,12 @@ sub apply{
 		$self->{changed}=0;
 	
 	}
-	
-	$self->_save_subforms;
+	if ($done) {
+		$self->_save_subforms;
 
-	$self->_set_record_status_label;
+		$self->_set_record_status_label;
+	}
+	return $done;
 }
 
 sub next{
@@ -760,7 +763,7 @@ sub _set_record_status_label {
 
 sub set_widget_value {
 	my ($self, $wid, $x) = @_;
-	$self->{log}->debug("set_widget_value: " . $wid . " to " . $x); 
+	$self->{log}->debug("set_widget_value: " . $wid . " to " . (defined $x ? $x : "null")); 
 	my $w = $self->{builder}->get_object($wid);
 	if ($w) {
 		my $coderef = $setter{ $self->{datawidgetsName}->{$wid} };
@@ -1181,9 +1184,7 @@ Return 1 if the data has been edited in the form and in any subform added with C
 
 =head1 SUPPORT
 
-Any Gk2::Ex::DbLinker questions or problems can be posted to the the mailing list. To subscribe to the list or view the archives, go here: 
-L<http://groups.google.com/group/gtk2-ex-dblinker>. 
-You may also send emails to gtk2-ex-dblinker@googlegroups.com. 
+Any Gk2::Ex::DbLinker questions or problems can be posted to me (rappazf) on my gmail account.  
 
 The current state of the source can be extract using Mercurial from
 L<http://code.google.com/p/gtk2-ex-dblinker/>.
