@@ -149,8 +149,10 @@ sub save{
 		$row =  $self->{data}[$pos];
 	}
 	$self->{log}->debug("saving and unsetting new row");
-	$row->save or carp("can't save ...\n");
+	my $done;
+	$done = $row->save or carp("can't save ...\n");
 	$self->{new_row} = undef;
+	return $done;
 }
 sub new_row {
 	my ($self ) = @_;
@@ -519,9 +521,7 @@ Return an array of autoincremented primary key(s) defined by the the 'serial' co
 
 =head1 SUPPORT
 
-Any Gk2::Ex::DbLinker questions or problems can be posted to the the mailing list. To subscribe to the list or view the archives, go here: 
-L<http://groups.google.com/group/gtk2-ex-dblinker>. 
-You may also send emails to gtk2-ex-dblinker@googlegroups.com. 
+Any Gk2::Ex::DbLinker questions or problems can be posted to me (rappazf) on my gmail account. 
 
 The current state of the source can be extract using Mercurial from
 L<http://code.google.com/p/gtk2-ex-dblinker/>.
